@@ -204,13 +204,17 @@ public abstract class AuctionInfo extends XMLSerializeSimple {
     xseller.setContents(_seller);
     xmlResult.addChild(xseller);
 
-    xstart = new XMLElement("start");
-    xstart.setContents(Long.toString(_start.getTime()));
-    xmlResult.addChild(xstart);
+    if(_start != null) {
+      xstart = new XMLElement("start");
+      xstart.setContents(Long.toString(_start.getTime()));
+      xmlResult.addChild(xstart);
+    }
 
-    xend = new XMLElement("end");
-    xend.setContents(Long.toString(_end.getTime()));
-    xmlResult.addChild(xend);
+    if(_end != null) {
+      xend = new XMLElement("end");
+      xend.setContents(Long.toString(_end.getTime()));
+      xmlResult.addChild(xend);
+    }
 
     xbidcount = new XMLElement("bidcount");
     xbidcount.setContents(Integer.toString(_numBids));
@@ -364,7 +368,7 @@ public abstract class AuctionInfo extends XMLSerializeSimple {
         String maxWidthString = JConfig.queryConfiguration("thumbnail.maxWidth", "256");
         String prefWidthString = JConfig.queryConfiguration("thumbnail.prefWidth", "128");
         String maxHeightString = JConfig.queryConfiguration("thumbnail.maxHeight", "256");
-        String prefHeightString = JConfig.queryConfiguration("thumbnail.prefWidth", "128");
+        String prefHeightString = JConfig.queryConfiguration("thumbnail.prefHeight", "128");
         int maxWidth = Integer.parseInt(maxWidthString);
         int prefWidth = Integer.parseInt(prefWidthString);
         int maxHeight = Integer.parseInt(maxHeightString);
@@ -507,7 +511,14 @@ public abstract class AuctionInfo extends XMLSerializeSimple {
   public void setIdentifier(String id) { _identifier = id; }
   public String getIdentifier() { return _identifier; }
 
-  public Currency getCurBid() { return(_curBid); }
+  public Currency getCurBid() {
+    Currency rval = Currency.NoValue();
+    if(_curBid != null && !_curBid.isNull()) rval = _curBid;
+
+    if (rval.isNull() && _buy_now != null && !_buy_now.isNull()) rval = _buy_now;
+    return(rval);
+  }
+
   public Currency getUSCurBid() {
     Currency rval = Currency.NoValue();
     if (_us_cur != null && !_us_cur.isNull()) {
@@ -515,6 +526,7 @@ public abstract class AuctionInfo extends XMLSerializeSimple {
     } else if(_curBid.getCurrencyType() == Currency.US_DOLLAR) {
       rval = _curBid;
     }
+    if(rval.isNull() && _buy_now_us != null && !_buy_now_us.isNull()) rval = _buy_now_us;
     return rval;
   }
   public Currency getMinBid() { if(_minBid != null) return(_minBid); else return _curBid; }
