@@ -360,40 +360,42 @@ public abstract class AuctionServer implements XMLSerialize {
   }
 
   public AuctionStats getStats() {
-    AuctionStats outStat = new AuctionStats();
-    outStat._count = _aucList.size();
-    long lastUpdateTime = Long.MAX_VALUE;
-    long lastEndedTime = Long.MAX_VALUE;
-    long lastSnipeTime = Long.MAX_VALUE;
+    synchronized (_aucList) {
+      AuctionStats outStat = new AuctionStats();
+      outStat._count = _aucList.size();
+      long lastUpdateTime = Long.MAX_VALUE;
+      long lastEndedTime = Long.MAX_VALUE;
+      long lastSnipeTime = Long.MAX_VALUE;
 
-    for (Iterator item = _aucList.iterator(); item.hasNext();) {
-      AuctionEntry ae = (AuctionEntry) item.next();
-      if(ae.isEnded()) {
-        outStat._completed++;
-      } else {
-        long thisTime = ae.getEndDate().getTime();
-        if(ae.isSniped()) {
-          outStat._snipes++;
-          if(thisTime < lastSnipeTime) {
-            outStat._nextSnipe = ae;
-            lastSnipeTime = thisTime;
+      for (Iterator item = _aucList.iterator(); item.hasNext();) {
+        AuctionEntry ae = (AuctionEntry) item.next();
+        if (ae.isEnded()) {
+          outStat._completed++;
+        } else {
+          long thisTime = ae.getEndDate().getTime();
+          if (ae.isSniped()) {
+            outStat._snipes++;
+            if (thisTime < lastSnipeTime) {
+              outStat._nextSnipe = ae;
+              lastSnipeTime = thisTime;
+            }
+          }
+
+          if (thisTime < lastEndedTime) {
+            outStat._nextEnd = ae;
+            lastEndedTime = thisTime;
+          }
+
+          long nextTime = ae.getNextUpdate();
+          if (nextTime < lastUpdateTime) {
+            outStat._nextUpdate = ae;
+            lastUpdateTime = nextTime;
           }
         }
-
-        if(thisTime < lastEndedTime) {
-          outStat._nextEnd = ae;
-          lastEndedTime = thisTime;
-        }
-
-        long nextTime = ae.getNextUpdate();
-        if(nextTime < lastUpdateTime) {
-          outStat._nextUpdate = ae;
-          lastUpdateTime = nextTime;
-        }
       }
-    }
 
-    return outStat;
+      return outStat;
+    }
   }
 
   public void fromXML(XMLElement inXML) {
@@ -448,7 +450,11 @@ public abstract class AuctionServer implements XMLSerialize {
     synchronized(_aucList) {
       for(Iterator it = _aucList.iterator(); it.hasNext(); ) {
         AuctionEntry ae = (AuctionEntry) it.next();
-        xmlResult.addChild(ae.toXML());
+        try {
+          xmlResult.addChild(ae.toXML());
+        } catch(Exception e) {
+          ErrorManagement.handleException("Exception trying to save auction " + ae.getIdentifier() + " (" + ae.getTitle() + ") -- Not saving", e);
+        }
       }
     }
 
@@ -576,12 +582,15 @@ public abstract class AuctionServer implements XMLSerialize {
     StringBuffer loadedPage;
 
     try {
-      String cookie = null;
       CookieJar curCook = getNecessaryCookie(false);
+      URLConnection uc;
       if(curCook != null) {
-        cookie = curCook.toString();
+        uc = curCook.getAllCookiesFromPage(auctionURL.toString(), null, false, null);
+      } else {
+        uc = Http.makeRequest(auctionURL, null);
       }
-      loadedPage = Http.receivePage(Http.makeRequest(auctionURL, cookie));
+      loadedPage = Http.receivePage(uc);
+      if(loadedPage != null && loadedPage.length() == 0) loadedPage = null;
     } catch(FileNotFoundException fnfe) {
       ErrorManagement.logDebug("Item not found: " + auctionURL.toString());
       throw fnfe;
@@ -698,7 +707,9 @@ public abstract class AuctionServer implements XMLSerialize {
       }
       MQFactory.getConcrete("Swing").enqueue("LINK UP");
     } else {
-      inEntry.setLastStatus("Failed to load from server!");
+      if(!inEntry.getLastStatus().equals("Seller away - item unavailable.")) {
+        inEntry.setLastStatus("Failed to load from server!");
+      }
       inEntry.setInvalid();
     }
 
@@ -724,8 +735,8 @@ public abstract class AuctionServer implements XMLSerialize {
     return new String(stripOut);
   }
 
-  protected Date figureDate(String endTime, String siteDateFormat) {
-    return figureDate(endTime, siteDateFormat, true);
+  protected Date figureDate(String endTime, String siteDateFormat, boolean ignore_badformat) {
+    return figureDate(endTime, siteDateFormat, true, ignore_badformat);
   }
 
   /** 
@@ -736,11 +747,12 @@ public abstract class AuctionServer implements XMLSerialize {
    * @param endTime - The string containing the human-readable time to be parsed.
    * @param siteDateFormat - The format describing the human-readable time.
    * @param strip_high - Whether or not to strip high characters.
-   * 
+   * @param ignore_badformat - Return null if the date is in a bad format.
+   *
    * @return - The date/time in Date format that was represented by
    * the human readable date string.
    */
-  protected Date figureDate(String endTime, String siteDateFormat, boolean strip_high) {
+  protected Date figureDate(String endTime, String siteDateFormat, boolean strip_high, boolean ignore_badformat) {
     String endTimeFmt = endTime;
     SimpleDateFormat sdf = new SimpleDateFormat(siteDateFormat, Locale.US);
 
@@ -757,8 +769,12 @@ public abstract class AuctionServer implements XMLSerialize {
       endingDate = sdf.parse(endTimeFmt);
       _officialServerTimeZone = sdf.getCalendar().getTimeZone();
     } catch(java.text.ParseException e) {
-      ErrorManagement.handleException("Error parsing date (" + endTimeFmt + "), setting to completed.", e);
-      endingDate = new Date();
+      if(!ignore_badformat) {
+        ErrorManagement.handleException("Error parsing date (" + endTimeFmt + "), setting to completed.", e);
+        endingDate = new Date();
+      } else {
+        endingDate = null;
+      }
     }
     return(endingDate);
   }
