@@ -517,7 +517,7 @@ public class Currency implements Comparable {
     otherValue = (Currency)inValue;
 
     sameCurrency = (otherValue.getCurrencyType() == _whatCurrency);
-    sameValue = ((int)otherValue.getValue()*1000) == ((int)_value*1000);
+    sameValue = ((int)(otherValue.getValue()*1000)) == ((int)(_value*1000));
 
     return(sameCurrency && sameValue);
   }
@@ -550,7 +550,7 @@ public class Currency implements Comparable {
       throw new CurrencyTypeException("Cannot compare different currencies.");
     }
 
-    lowerValue = Double.compare( (double)((int)otherValue.getValue()*1000), (double)(int)_value*1000) == 1;
+    lowerValue = Double.compare( (double)((int)(otherValue.getValue()*1000)), (double)(int)(_value*1000)) == 1;
 
     return(lowerValue);
   }
